==> huaweicloudsdkief-3.1.113-py2.py3-none-any.whl: huaweicloudsdkief/v1/model/updata_app_version_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdataAppVersionBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'version': 'VersionUpdate'
    }

    attribute_map = {
        'version': 'version'
    }

    def __init__(self, version=None):
        """UpdataAppVersionBody

        The model defined in huaweicloud sdk

        :param version: 
        :type version: :class:`huaweicloudsdkief.v1.VersionUpdate`
        """
        
        

        self._version = None
        self.discriminator = None

        self.version = version

    @property
    def version(self):
        """Gets the version of this UpdataAppVersionBody.

        :return: The version of this UpdataAppVersionBody.
        :rtype: :class:`huaweicloudsdkief.v1.VersionUpdate`
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this UpdataAppVersionBody.

        :param version: The version of this UpdataAppVersionBody.
        :type version: :class:`huaweicloudsdkief.v1.VersionUpdate`
        """
        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdataAppVersionBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkief-3.1.153-py2.py3-none-any.whl: huaweicloudsdkief/v1/model/updata_app_version_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdataAppVersionBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'version': 'VersionUpdate'
    }

    attribute_map = {
        'version': 'version'
    }

    def __init__(self, version=None):
        r"""UpdataAppVersionBody

        The model defined in huaweicloud sdk

        :param version: 
        :type version: :class:`huaweicloudsdkief.v1.VersionUpdate`
        """
        
        

        self._version = None
        self.discriminator = None

        self.version = version

    @property
    def version(self):
        r"""Gets the version of this UpdataAppVersionBody.

        :return: The version of this UpdataAppVersionBody.
        :rtype: :class:`huaweicloudsdkief.v1.VersionUpdate`
        """
        return self._version

    @version.setter
    def version(self, version):
        r"""Sets the version of this UpdataAppVersionBody.

        :param version: The version of this UpdataAppVersionBody.
        :type version: :class:`huaweicloudsdkief.v1.VersionUpdate`
        """
        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdataAppVersionBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
